@@ -24,6 +24,8 @@
 #ifndef __GST_VERSION_H__
 #define __GST_VERSION_H__
 
+G_BEGIN_DECLS
+
 /*
  * Use these only when you want to know what GStreamer version your stuff was
  * compiled against.
@@ -32,8 +34,10 @@
  */
 #define GST_VERSION_MAJOR (0)
 #define GST_VERSION_MINOR (8)
-#define GST_VERSION_MICRO (7)
+#define GST_VERSION_MICRO (10)
 
 void    gst_version     (guint *major, guint *minor, guint *micro);
 
+G_END_DECLS
+
 #endif /* __GST_VERSION_H__ */
